#!/usr/bin/python
import sys
import griddb_python_client

if len(sys.argv) < 6:
	print("Need to enter host, port, clusterName, username, password to run this sample program")
	sys.exit(1)

## Get GridDB connection and cluster settings from command-lin
host = sys.argv[1]
port = sys.argv[2]
clusterName = sys.argv[3]
user = sys.argv[4]
password = sys.argv[5]

griddb = griddb_python_client 
factory = griddb.StoreFactory.get_default()


try:
	## Fetch GridStore
	gridstore = factory.get_store({
		"notficationAddress":host,
		"notificationPort":port,
		"clusterName":clusterName,
		"user":user,
		"password":password
		})

	## Create timeseries Schema and insert into GridDB
	timeseries = gridstore.put_container("voltmeter2",[
		("timestamp",griddb.GS_TYPE_TIMESTAMP),
		("active",griddb.GS_TYPE_BOOL),
		("voltage",griddb.GS_TYPE_DOUBLE)
		],griddb.GS_CONTAINER_TIME_SERIES)

	## Create rows and set all Row Fields
	#insertionRow = [("timestamp",griddb.Timestamp_current()),("active",True),("voltage",12.34)]
	insertionRow = timeseries.create_row()
	# insertionRow.set_field_by_timestamp(0,griddb.Timestamp_add_time(griddb.Timestamp_current(),-6,griddb.GS_TIME_UNIT_HOUR)) ## Insert timestamp from past 6 hours
	# insertionRow.set_field_by_bool(1,True) ## Set active value
	# insertionRow.set_field_by_double(2, 12.34) ## Set voltage value
	insertionRow.timestamp = griddb.Timestamp_current()
	# insertionRow.timestamp = griddb.Timestamp_add_time(griddb.Timestamp_current(),-6,griddb.GS_TIME_UNIT_HOUR)
	insertionRow.active = True
	insertionRow.voltage = 12.34

	## Insert row into Timeseries container
	timeseries.put_row(insertionRow)

	time = None

	## Create a Time-specific TQL query and fetch into a RowSet
	## Look for all records in the past 12 hours
	row = timeseries.create_row()
	query = timeseries.query("select *")
	# query = timeseries.query("select * where timestamp > TIMESTAMPADD(HOUR,NOW(),-12)")
	rowSet = query.fetch(False)

	while rowSet.has_next():
		#print("HI")
		rowSet.get_next(row) ## Obtain row objects
		print(row.timestamp)
		# active = row.active
		# voltage = row.voltage
		time = row.get_field_as_timestamp(0) ## Obtain timestamp from row
		voltage = row.get_field_as_double(2) ## Obtain voltage from row
		print("Voltage at timestamp: {0} is {1} volts in Timeseries voltmeter2".format(time,voltage)) ## Display time and voltage

	#timeseries.delete_row_by_timestamp(time)
	gridstore.drop_container("voltmeter2")

except griddb.GSException as e:
	print(e.what())
