#!/usr/bin/ruby
$:.unshift File.dirname(__FILE__)
require 'griddb_ruby_client'
Griddb = Griddb_ruby_client

begin
	factory = Griddb::StoreFactory.get_default()

	## Fetch a Gridstore Instance
	gridstore = factory.get_store({
		"notificationAddress"=> ARGV[0],
		"notificationPort"=> ARGV[1],
		"clusterName"=> ARGV[2],
		"user"=> ARGV[3],
		"password"=> ARGV[4]
		})

	## Insert a Collection into GridDB
	collection = gridstore.put_container("collection121",[
		{"name"=>Griddb::GS_TYPE_STRING},
		{"status"=>Griddb::GS_TYPE_BOOL},
		{"count"=>Griddb::GS_TYPE_LONG},
		{"lob"=>Griddb::GS_TYPE_BLOB}],
		Griddb::GS_CONTAINER_COLLECTION)

	## Set auto commit
	collection.set_auto_commit(false)

	#Set an index on the Row-key Column, Create String Index
	collection.create_index("name",Griddb::GS_INDEX_FLAG_DEFAULT)

	#Set an index on the Column, Create Integer Index
	collection.create_index("count",Griddb::GS_INDEX_FLAG_DEFAULT)

	#Create and set row data
	## Instantiate a Blob Array
	blob = [65, 66, 67, 68, 69, 70, 71, 72, 73, 74].pack("U*")

	## Instantiate first row 
	firstRow = collection.create_row()

	## Set Row Fields
	firstRow.set_field_by_string(0,"firstRow")
	firstRow.set_field_by_bool(1,false)
	firstRow.set_field_by_long(2,5)
	firstRow.set_field_by_blob(3,blob)

	## Insert initial Row into Collection
	update = true
	ret = collection.put_row(firstRow)

	## Fetch the row by its index, 'name'
	secondRow = collection.create_row()
	collection.get_row_by_string("firstRow",true,secondRow)
	collection.delete_row_by_string("firstRow")

	## Create a new row-id and make a new Row
	collection.put_row_by_string("secondRow",secondRow)
	collection.commit()

	## Make a query Object
	query=collection.query("select * where name = 'secondRow'")
	row = collection.create_row()

	## Create, issue, and fetch the query
	rowSet = query.fetch(update)

	while rowSet.has_next()
		rowSet.get_next(row) ## Obtain the row object
		name = row.get_field_as_string(0) ## Obtain the name from the row
		status = row.get_field_as_bool(1) ## Obtain the status
		count = row.get_field_as_long(2) + 1   ## Obtain and increment the 'count' column from the 
		lob = row.get_field_as_blob(3) ## Get blob array
		print "Row in Collection: collection121, Person: name=#{name} status=#{status} count=#{count} lob="
    	p lob.unpack("U*")
		row.set_field_by_long(2,count) ## Update the row with new 'count' column value
		rowSet.update_current(row) ## Update rowSet with new row
	end
	collection.commit()

	### Insert a Timeseries into GridDB
	timeseries = gridstore.put_container("voltmeter502",[
		{"timestamp"=>Griddb::GS_TYPE_TIMESTAMP},
		{"amperage"=>Griddb::GS_TYPE_DOUBLE},
		{"voltage"=>Griddb::GS_TYPE_DOUBLE}
		],Griddb::GS_CONTAINER_TIME_SERIES)

	timestamps = []
	timeRow = timeseries.create_row()
	for i in 0..4
		timestamp = Griddb::Timestamp.add_time(Griddb::Timestamp.current(),i * -2,Griddb::GS_TIME_UNIT_MINUTE)  ## Perform time adding operation
		timeRow.set_field_by_timestamp(0,timestamp) ## Set row with timestamp value
		timeRow.set_field_by_double(1,(i * 2) + 3.5)
		timeRow.set_field_by_double(2,(i * 3) + 4.5)
		timeseries.put_row(timeRow) ## Insert row into the Timeseries
	end

	update = false
	timestamp =  Griddb::Timestamp.current()  ## Get current time
	aggCommand = "select AVG(voltage) from voltmeter502 where timestamp > TIMESTAMPADD(MINUTE,TO_TIMESTAMP_MS(#{timestamp}), -10) AND timestamp < TIMESTAMPADD(MINUTE,TO_TIMESTAMP_MS(#{timestamp}), 10)"
	aggQuery = timeseries.query(aggCommand) 
	aggRowSet = aggQuery.fetch(update) ## Create, issue, and fetch query from the Timeseries 
	while aggRowSet.has_next()
	      aggResult = aggRowSet.get_next_aggregation() ## Get Aggregation Result and obtain and display its numerical result
	      print "Aggregation result from voltmeter502: Average voltage = #{aggResult.get_double()}\n"
	end

rescue Griddb::GSException => e
  print "#{e.what()}\n"
end








